==> react-native-hotqa-sdk-0.0.22.tgz: package/src/components/reorder/index2.js <==
import React, {useRef} from 'react';
import {StyleSheet, View} from 'react-native';
import {onConfigurations} from '../../common/helper';
import Tags from '../tag/Tags';

export default (props) => {
  const {item, dispatch} = props;
  let _tagsComponent0 = useRef(null);
  let _tagsComponent1 = useRef(null);
  let {configurations} = item;
  configurations = JSON.parse(configurations);
  const arrData = configurations.correct_answer;
  arrData.sort();

  const dataSelected = [];
  arrData.forEach((i) => {
    dataSelected.push('');
  });

  const onDragEnd = (data) => {
    let convertData = [];
    data.forEach((item) => {
      convertData.push(item.title);
    });
    onConfigurations(item, convertData, dispatch);
  };

  const onSubmitNewTag = (tag, type, refTag) => {
    refTag && refTag.onSubmitNewTag(tag, type);
  };

  return (
    <View style={styles.configView}>
      <Tags
        ref={(component) => (_tagsComponent0 = component)}
        tags={arrData}
        type={0}
        onDragRelease={(data) => onDragEnd(data)}
        onPress={(tag) => onSubmitNewTag(tag, 0, _tagsComponent1)}
      />
      <View style={{marginTop: 100}}>
        <Tags
          ref={(component) => (_tagsComponent1 = component)}
          tags={dataSelected}
          type={1}
          onDragRelease={(data) => onDragEnd(data)}
          onPress={(tag) => onSubmitNewTag(tag, 1, _tagsComponent0)}
        />
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flex: 1,
    alignItems: 'center',
  },
  text: {
    color: 'black',
    fontSize: 14,
  },
  item: {
    paddingVertical: 8,
    paddingHorizontal: 20,
    alignItems: 'center',
    justifyContent: 'center',
    marginHorizontal: 4,
    borderColor: '#FDA429',
    borderWidth: 2,
    borderRadius: 20,
    marginHorizontal: 5,
  },
});

==> react-native-hotqa-sdk-0.0.25.tgz: package/src/components/reorder/index2.js <==
import React, {useRef} from 'react';
import {StyleSheet, View, Text} from 'react-native';
import {onConfigurations} from '../../common/helper';
import Tags from '../tag/Tags';
import SharePreference from '../../common/SharePreference';

export default (props) => {
  const {item, dispatch, isFinish} = props;
  let _tagsComponent0 = useRef(null);
  let _tagsComponent1 = useRef(null);
  let {configurations} = item;
  configurations = JSON.parse(configurations);
  const correctAnswer = configurations.correct_answer;

  const arrData = [];
  const dataSelected = [];
  correctAnswer.forEach((i) => {
    arrData.push(i);
    dataSelected.push('');
  });
  arrData.sort();

  // arrData.forEach((i) => {
  //   dataSelected.push('');
  // });

  const onDragEnd = (data) => {
    if (!isFinish) {
      let convertData = [];
      data.forEach((item) => {
        convertData.push(item.title);
      });
      onConfigurations(item, convertData, dispatch);
    }
  };

  const onSubmitNewTag = (tag, type, refTag) => {
    if (!isFinish) {
      refTag && refTag.onSubmitNewTag(tag, type);
    }
  };

  return (
    <View style={styles.configView}>
      <Tags
        ref={(component) => (_tagsComponent0 = component)}
        tags={arrData}
        type={0}
        tagSelected={false}
        onDragRelease={(data) => onDragEnd(data)}
        onPress={(tag) => onSubmitNewTag(tag, 0, _tagsComponent1)}
      />
      <View style={{marginTop: 100}}>
        <Tags
          ref={(component) => (_tagsComponent1 = component)}
          tags={dataSelected}
          type={1}
          tagSelected={true}
          onDragRelease={(data) => onDragEnd(data)}
          onPress={(tag) => onSubmitNewTag(tag, 1, _tagsComponent0)}
        />
      </View>
      {isFinish && (
        <Text style={styles.textAnswer}>
          Đáp án:{'   '} {correctAnswer}
        </Text>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flex: 1,
    alignItems: 'center',
  },
  text: {
    color: 'black',
    fontSize: 14,
  },
  item: {
    paddingVertical: 8,
    paddingHorizontal: 20,
    alignItems: 'center',
    justifyContent: 'center',
    borderColor: '#FDA429',
    borderWidth: 2,
    borderRadius: 20,
    marginHorizontal: 5,
  },
  textAnswer: {
    color: 'red',
    fontSize: 16,
    marginTop: 100,
  },
});
